.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
collective.vocabularies.technology
==============================================================================

Adds vocabularies for terms and jargons used in the tech industry to your Plone site.

Features
--------

- collective.vocabularies.technology.IPlatformTypes
- collective.vocabularies.technology.IProgammingLanguages


Installation
------------

Install collective.vocabularies.technology by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.vocabularies.technology


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.vocabularies.technology/issues
- Source Code: https://github.com/collective/collective.vocabularies.technology


Support
-------

If you are having issues, please let us know.
We have a mailing list located at: b4.oshany@gmail.com


License
-------

The project is licensed under the GPLv2.
